import React, { useEffect } from "react";
import {
	Container,
	Typography,
	CircularProgress,
	Card,
	CardContent,
	Grid,
	Avatar,
	Box,
} from "@mui/material";

import { useDispatch, useSelector } from "react-redux";
import { AppDispatch, RootState } from "../../redux/store/store";
import { fetchProfile } from "../../redux/slices/authSlice";
const ProfilePage = () => {
	// const dispatch = useDispatch();

	const dispatch = useDispatch<AppDispatch>();
	//Created by : jaanvi and Eknoor
	//date: 12-feb-25
	//Extract user profile data from Auth
	// Extract profile, loading, and error state from Redux
	const { user, isLoading, error } = useSelector(
		(state: RootState) => state.auth
	);

	useEffect(() => {
		// Dispatch the getProfile thunk to fetch user profile data

		dispatch(fetchProfile());
	}, [dispatch]);

	if (isLoading) {
		return (
			<Box
				sx={{
					display: "flex",
					justifyContent: "center",
					alignItems: "center",
					height: "100vh",
				}}
			>
				<CircularProgress />
			</Box>
		);
	}

	if (error) {
		return (
			<Container>
				<Typography variant="h5" color="error" gutterBottom>
					Error: {error}
				</Typography>
			</Container>
		);
	}

	if (!user) {
		return (
			<Container>
				<Typography variant="h5">No profile data available</Typography>
			</Container>
		);
	}

	return (
		<Container sx={{ py: 4 }}>
			<Typography variant="h4" gutterBottom>
				Profile
			</Typography>
			<Card sx={{ maxWidth: 600, margin: "0 auto" }}>
				<CardContent>
					<Grid container spacing={2} alignItems="center">
						<Grid item>
							<Avatar
								alt={user?.name || "User Avatar"}
								src={"/static/images/avatar/7.jpg"}
								sx={{ width: 80, height: 80 }}
							/>
						</Grid>
						<Grid item xs>
							<Typography variant="h6">
								{user?.name || "N/A"}
							</Typography>
							<Typography variant="body2" color="text.secondary">
								Email: {user?.email || "N/A"}
							</Typography>
							<Typography variant="body2" color="text.secondary">
								Phone: {user?.phone || "N/A"}
							</Typography>
							<Typography variant="body2" color="text.secondary">
								Role: {user?.role || "N/A"}
							</Typography>
						</Grid>
					</Grid>
				</CardContent>
			</Card>
		</Container>
	);
};

export default ProfilePage;